..
    Copyright (C) 2020 CERN.
    Copyright (C) 2020 Northwestern University.

    Marshmallow-Utils is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version 0.1.5 (released 2020-09-24)

- Fix to expand querystring params correctly

Version 0.1.4 (released 2020-09-17)

- Adds LinksSchema similar to LinksField

Version 0.1.3 (released 2020-09-16)

- Moved additional utilities into the library.

Version 0.1.2 (released 2020-09-16)

- Ported GenFunction and GenMethod

Version 0.1.1 (released 2020-09-11)

- Minor fix to allow a lower ftfy package version than the latest.

Version 0.1.0 (released 2020-09-11)

- Initial public release.
